@@ -475,6 +475,11 @@
                     #:debian-suite
                     #:debian-architecture
                     #:debian-architecture-string
+                    #:freebsd
+                    #:freebsd-release
+                    #:freebsd-devel
+                    #:freebsd-architecture
+                    #:freebsd-version
 
                     #:typecase
                     #:host-typecase
@@ -489,6 +494,15 @@
                     #:required
                     #:supports-arch-p))
 
+  (package :consfigurator.property.rc.conf
+           (:local-nicknames (#:os  #:consfigurator.property.os))
+           (:export #:contains
+                    #:file-contains
+                    #:ws-list-contains
+                    #:ws-list-lacks
+                    #:file-ws-list-contains
+                    #:file-ws-list-lacks))
+
   (package :consfigurator.property.container
            (:export #:contained
                     #:contained-p
@@ -557,8 +571,18 @@
                     #:pinned
                     #:no-pdiffs))
 
+  (package :consfigurator.property.pkgng
+           (:local-nicknames (#:os      #:consfigurator.property.os))
+           (:export #:installed
+                    #:deleted
+                    #:upgraded
+                    #:autoremoved
+                    #:cache-cleaned
+                    #:cache-emptied))
+
   (package :consfigurator.property.package
-           (:local-nicknames (#:apt #:consfigurator.property.apt))
+           (:local-nicknames (#:apt   #:consfigurator.property.apt)
+                             (#:pkgng #:consfigurator.property.pkgng))
            (:export #:+consfigurator-system-dependencies+
                     #:package-manager-not-found
                     #:installed))
